to property

B Function(A) to
final

Transforms a value from type A to type B.

This should be the inverse of from, such that from(to(a)) == a for all values a.

Implementation

final B Function(A) to;