dispose method

void dispose()

Cancels any pending execution and cleans up the timer.

Call this when you no longer need the debouncer to prevent the action from executing unexpectedly.

Implementation

void dispose() {
  _timer?.cancel();
}