FlattenResultExtension<T extends Object?, E extends Object> extension

Extension methods for flattening nested result types.

Useful when you have a Result containing another Result and need to flatten it into a single result. This is the join/mu operation in monad terminology.

on

Methods

flatten() Result<T, E>

Available on Result<Result<T, E>, E>, provided by the FlattenResultExtension extension

Flattens a nested Result into a single Result.