value property
T
value
final
The final computed value that will be returned by the trampoline.
Implementation
final T value;
The final computed value that will be returned by the trampoline.
final T value;