next property

Bounce<T> Function() next
final

A lazy function that produces the next computation step.

The trampoline calls this function to get the next Bounce. Wrap recursive calls in this thunk to avoid direct recursion:

// Good: deferred recursion
return More(() => recursiveStep(n - 1));

// Bad: would still be recursive
return More(recursiveStep(n - 1));

Implementation

final Bounce<T> Function() next;