from property
A Function(B)
from
final
Transforms a value from type B to type A.
This should be the inverse of to, such that
to(from(b)) == b for all values b.
Implementation
final A Function(B) from;