get property
Part Function(Whole)
get
final
Extracts the focused Part from the Whole.
This function retrieves the value that this lens focuses on. It must be consistent with set: getting after setting the same value should be observable as identity.
Implementation
final Part Function(Whole) get;