Bounce<T extends Object?> class
sealed
Base class for computations in the trampoline pattern.
A Bounce represents either:
This sealed class restricts implementations to More and Done, ensuring type safety in the trampoline execution.
Constructors
- Bounce.done(T value)
-
constfactory
-
Bounce.more(Bounce<
T> action()) -
constfactory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited