More<T extends Object?> constructor
const
More<T extends Object?> (
- Bounce<
T> next()
Creates a pending computation with the given next thunk.
The next function will be called by the trampoline to get the
next bounce in the chain. This deferral is key to preventing
stack overflow in deep recursion.
Implementation
const More(this.next);